@@ -2,6 +2,7 @@ import os
 from pathlib import Path
 
 from PySide6.QtCore import Qt, QUrl
+from PySide6.QtGui import QIcon
 from PySide6.QtMultimedia import QSoundEffect
 from PySide6.QtWidgets import QWidget, QMessageBox
 
@@ -13,14 +14,20 @@ class SoundEffectWidget(QWidget):
         self.setWindowFlag(
             Qt.WindowType.WindowTransparentForInput |
             Qt.WindowType.FramelessWindowHint |
-            Qt.WindowType.WindowStaysOnTopHint
+            Qt.WindowType.WindowStaysOnTopHint |
+            Qt.WindowType.Tool
         )
         self.setAttribute(Qt.WidgetAttribute.WA_TranslucentBackground)
         self.sound_player = QSoundEffect()
         self.sound_path = Path(sound_path)
         if self.sound_path.exists() and self.sound_path.is_file():
-            self.sound_player.setSource(QUrl.fromLocalFile(str(self.sound_path)))
+            # QUrl non ascii path encode, Avoid read wrong path and file name
+            source = QUrl.fromLocalFile(str(self.sound_path).encode())
+            source = source.fromEncoded(source.toEncoded())
+            self.sound_player.setSource(source)
             self.sound_player.setVolume(volume)
+            # -2 means loop forever
+            self.sound_player.setLoopCount(-2)
             self.sound_player.play()
         else:
             message_box = QMessageBox(self)
@@ -30,8 +37,9 @@ class SoundEffectWidget(QWidget):
         self.setWindowTitle("Sound Wave")
         # Set Icon
         self.icon_path = Path(os.getcwd() + "/je_driver_icon.ico")
+        if self.icon_path.exists() and self.icon_path.is_file():
+            self.setWindowIcon(QIcon(str(self.icon_path)))
 
-    def close(self):
-        super().close()
+    def closeEvent(self, event):
+        super().closeEvent(event)
         self.sound_player.stop()
-
